@@ -1,8 +1,10 @@
+from typing import List
+
 from sym.cli.actions.sym_action import SymAction
 from sym.cli.data.request_data import RequestData
 from sym.cli.helpers.check.core import DependenciesCheck, SymCheck
 from sym.cli.helpers.ec2.factory import get_ec2_client
-from sym.cli.helpers.ssh import start_tunnel
+from sym.cli.helpers.ssh import ensure_public_key_on_instance, start_tunnel
 from sym.cli.saml_clients.saml_client_factory import SAMLClientFactory
 
 
@@ -10,7 +12,7 @@ class SSHSessionAction(SymAction):
     def __init__(self):
         super().__init__("ssh_session")
 
-    def get_requirements(self) -> [SymCheck]:
+    def get_requirements(self) -> List[SymCheck]:
         return [DependenciesCheck("aws"), DependenciesCheck("session-manager-plugin")]
 
     def execute(self, request_data: RequestData):
@@ -25,4 +27,8 @@ class SSHSessionAction(SymAction):
         )
 
         new_client = SAMLClientFactory.clone(client, aws_region=running_instance.region)
+        if request_data.params["ensure_key"]:
+            ensure_public_key_on_instance(
+                client, running_instance.instance_id, target_options.port
+            )
         start_tunnel(new_client, running_instance.instance_id, target_options.port)
