@@ -33,6 +33,7 @@ def ansible_playbook(
     control_master: bool,
     send_command: bool,
     forks: int,
+    command_timeout: int,
 ) -> None:
     """Run Ansible commands against an inventory of EC2 instances, using
     approved credentials from the Sym RESOURCE group.
@@ -57,6 +58,7 @@ def ansible_playbook(
         forks=forks,
         ansible_aws_profile=ansible_aws_profile,
         ansible_sym_resource=ansible_sym_resource,
+        ssm_timeout=command_timeout,
     )
 
     request_data = RequestData(
