@@ -1,9 +1,9 @@
 import click
 
+from sym.cli.decorators import command_require_bins, loses_interactivity, require_login
+from sym.cli.helpers.global_options import GlobalOptions
 from sym.cli.saml_clients.saml_client_factory import SAMLClientFactory
 
-from ..decorators import command_require_bins, loses_interactivity, require_login
-from ..helpers.global_options import GlobalOptions
 from ..helpers.options import resource_argument
 from .sym import sym
 
