@@ -1,4 +1,7 @@
+from typing import Optional
+
 import click
+from click_option_group import MutuallyExclusiveOptionGroup, optgroup
 
 from sym.cli.actions.action_registry import ActionRegistry
 from sym.cli.data.request_data import RequestData
@@ -19,9 +22,18 @@ from .sym import sym  # TODO: this should be an absolute import
     show_default=True,
     type=click.Path(exists=True, dir_okay=False, writable=True),
 )
-@click.option(
+@optgroup.group(
+    "Profile Name",
+    cls=MutuallyExclusiveOptionGroup,
+    help="Settings which change the profile that credentials are written to",
+)
+@optgroup.option(
     "--profile",
-    help="Profile name to write credentials to",
+    help="Profile name",
+)
+@optgroup.option(
+    "--prefix",
+    help="Prefix for profile name",
     default="sym",
     show_default=True,
 )
@@ -29,7 +41,13 @@ from .sym import sym  # TODO: this should be an absolute import
 @command_require_bins("aws", "session-manager-plugin")
 @require_login
 @loses_interactivity
-def write_creds(options: GlobalOptions, resource: str, path: str, profile: str) -> None:
+def write_creds(
+    options: GlobalOptions,
+    resource: str,
+    path: str,
+    profile: Optional[str],
+    prefix: str,
+) -> None:
     """Write out approved credentials for the specified Sym RESOURCE to
     a profile in your AWS credentials file.
 
@@ -41,6 +59,6 @@ def write_creds(options: GlobalOptions, resource: str, path: str, profile: str)
         action="write_creds",
         resource=resource,
         global_options=options,
-        params={"path": path, "profile": profile},
+        params={"path": path, "profile": profile, "prefix": prefix},
     )
     ActionRegistry.execute(request_data)
