@@ -10,7 +10,7 @@ from textwrap import dedent
 from typing import List, Sequence, Tuple
 
 import click
-from sym.shared.cli.helpers.contexts import push_env
+from sym.shared.cli.helpers.contexts import push_env, push_envs
 
 from sym.cli.decorators import intercept_errors, retry, run_subprocess
 from sym.cli.errors import (
@@ -38,6 +38,11 @@ from sym.cli.saml_clients.saml_client import SAMLClient
 MissingPublicKeyPattern = re.compile(r"Permission denied \(.*publickey.*\)")
 ConnectionClosedPattern = re.compile(r"Connection to .* closed")
 
+AWS_ERROR_PATTERNS = {
+    TargetNotConnectedPattern: TargetNotConnected,
+    AccessDeniedPattern: AccessDenied,
+}
+
 SSHConfigPath = "ssh/config"
 SSHKeyPath = "ssh/key"
 
@@ -101,39 +106,43 @@ def maybe_gen_ssh_key(client):
         gen_ssh_key(ssh_key, client.options)
 
 
-def ssh_args(client, instance, port) -> tuple:
+def ssh_tunnel_opts(client) -> dict:
     _, ssh_config = ssh_key_and_config(client)
-    opts = {
-        "p": str(port),
+    return {
         "F": str(ssh_config),
-        "l": get_ssh_user(),
         "v": client.debug,
     }
-    return (
-        "ssh",
-        instance,
-        opts,
-        f"-o HostKeyAlias={instance}",
-    )
+
+
+def ssh_args(client, instance, port) -> tuple:
+    opts = {"p": str(port), "l": get_ssh_user(), **ssh_tunnel_opts(client)}
+    return ("ssh", instance, opts, {"o": f"HostKeyAlias={instance}"})
 
 
 @run_subprocess
 def _start_background_ssh_session(client: SAMLClient, instance: str, port: int, *command):
-    with push_env("SHELL", "/bin/bash"):
+    with push_envs({"SHELL": "/bin/bash", "SYM_SKIP_ENSURE_KEY": "1"}):
         yield (
             *ssh_args(client, instance, port),
             {"f": True},
-            "-o BatchMode=yes",
+            {"o": "BatchMode=yes"},
             *command,
         )
 
 
 @run_subprocess
 def _start_ssh_session(client: SAMLClient, instance: str, port: int, *command: str):
-    with push_env("SHELL", "/bin/bash"):
+    with push_envs({"SHELL": "/bin/bash", "SYM_SKIP_ENSURE_KEY": "1"}):
         yield (*ssh_args(client, instance, port), *command)
 
 
+@intercept_errors(AWS_ERROR_PATTERNS, suppress=True)
+@run_subprocess
+def _start_ssh_tunnel(client: SAMLClient, program: str, *opts: str):
+    with push_env("SHELL", "/bin/bash"):
+        yield (program, ssh_tunnel_opts(client), *opts)
+
+
 @intercept_errors(suppress=True)
 @run_subprocess
 def raw_ssh(*args):
@@ -181,6 +190,12 @@ def _preprocess_args(client: SAMLClient, instance: str, args: Sequence[str]) ->
     return processed
 
 
+def start_ssh_tunnel(client: SAMLClient, program: str, opts: Sequence[str]):
+    ensure_ssh_config(client)
+    client.dprint("starting SSH tunnel")
+    _start_ssh_tunnel(client, program, *opts)
+
+
 @retry(TargetNotConnected, delay=1, count=2)
 @retry(MissingPublicKey, delay=0, count=2)
 def start_ssh_session(
@@ -206,13 +221,7 @@ def start_ssh_session(
             raise MissingPublicKey(err, get_ssh_user()) from err
 
         # If the ssh key path is cached then this doesn't get intercepted in ensure_ssh_key
-        raise_if_match(
-            {
-                TargetNotConnectedPattern: TargetNotConnected,
-                AccessDeniedPattern: AccessDenied,
-            },
-            err.stderr,
-        )
+        raise_if_match(AWS_ERROR_PATTERNS, err.stderr)
 
         if wrap:
             raise WrappedSubprocessError(
@@ -258,13 +267,20 @@ def gen_local_ssh_config(client) -> SymConfigFile:
     return ssh_config
 
 
+@retry(TargetNotConnected, delay=1, count=2)
+@intercept_errors(AWS_ERROR_PATTERNS, suppress=True)
 def ensure_public_key_on_instance(
     client,
     instance: str,
     port: int,
     *,
     args: Sequence[str] = [],
+    ttl: timedelta = timedelta(days=1),
 ):
+    if Config.check_instance_ttl(instance, ttl):
+        client.dprint(f"Skipping remote SSH key check for {instance}")
+        return
+
     try:
         _start_background_ssh_session(
             client, instance, port, *args, "exit", capture_output_=True
@@ -280,24 +296,14 @@ def ensure_public_key_on_instance(
         Config.touch_instance(instance)
 
 
-@retry(TargetNotConnected, delay=1, count=2)
-@intercept_errors({TargetNotConnectedPattern: TargetNotConnected}, suppress=True)
-def ensure_ssh_key(
-    client,
-    instance: str,
-    port: int,
-    *,
-    ttl: timedelta = timedelta(days=1),
-    args: Sequence[str] = [],
-):
+def ensure_ssh_config(client):
     gen_local_ssh_config(client)
     maybe_gen_ssh_key(client)
 
-    if Config.check_instance_ttl(instance, ttl):
-        client.dprint(f"Skipping remote SSH key check for {instance}")
-        return
 
-    ensure_public_key_on_instance(client, instance, port, args=args)
+def ensure_ssh_key(client, instance: str, port: int):
+    ensure_ssh_config(client)
+    ensure_public_key_on_instance(client, instance, port)
 
 
 def _set_handlers(instance):
