@@ -7,3 +7,7 @@ def validate_resource(resource: str):
         return True
     except KeyError:
         return False
+
+
+def validate_bool_str(bool_str: str):
+    return bool_str.lower() in {"true", "false"}
