@@ -192,6 +192,13 @@ class SAMLClient(ABC):
         env_vars = re.findall(r"([\w_]+)=(.+)\n", output)
         return {k: v for k, v in env_vars if k in self._cred_env_vars}
 
+    def has_creds(self) -> bool:
+        try:
+            self.get_creds()
+            return True
+        except Exception:
+            return False
+
     def _creds_expiring(self, buffer=timedelta(minutes=2)):
         try:
             creds = self.get_creds()
