@@ -4,6 +4,8 @@ from contextlib import ExitStack
 from typing import Dict, List
 
 import pytest
+from sym.shared.cli.helpers.contexts import push_envs
+from sym.shared.cli.tests.helpers.capture import CaptureCommand, c
 
 from sym.cli.constants.env import (
     ANSIBLE_CONNECTION_PLUGINS,
@@ -23,9 +25,7 @@ from sym.cli.constants.env import (
     YES,
 )
 from sym.cli.helpers.ansible import ansible_connection_plugins_value
-from sym.cli.helpers.contexts import push_envs
 from sym.cli.helpers.params import get_ssh_user
-from sym.cli.tests.helpers.capture import CaptureCommand, c
 from sym.cli.tests.helpers.sandbox import Sandbox
 
 INVENTORY = "inventory.file"
@@ -258,7 +258,7 @@ def test_ansible_playbook_send_command(
             "--connection=sym_aws_ssm",
             "--forks=10",
             f"--user={get_ssh_user()}",
-            f"--extra-vars=ansible_aws_ssm_bucket='sym-ansible-{TEST_ACCOUNT}' ansible_aws_ssm_host_cmd='sym --saml-client aws-profile --log-dir {os.environ['SYM_LOG_DIR']} host-to-instance sym-ansible-test $HOST --json' ansible_aws_ssm_region='us-east-1' ansible_aws_ssm_profile='sym-ansible-test'",
+            f"--extra-vars=ansible_aws_ssm_bucket='sym-ansible-{TEST_ACCOUNT}' ansible_aws_ssm_host_cmd='sym --saml-client aws-profile --log-dir {os.environ['SYM_LOG_DIR']} host-to-instance sym-ansible-test $HOST --json' ansible_aws_ssm_region='us-east-1' ansible_aws_ssm_profile='sym-ansible-test' ansible_aws_ssm_timeout='120'",
         ]
         capture_command.assert_commands(
             [
@@ -294,7 +294,7 @@ def test_ansible_playbook_send_command_low_forks(
             "--connection=sym_aws_ssm",
             "--forks=5",
             f"--user={get_ssh_user()}",
-            f"--extra-vars=ansible_aws_ssm_bucket='sym-ansible-{TEST_ACCOUNT}' ansible_aws_ssm_host_cmd='sym --saml-client aws-profile --log-dir {os.environ['SYM_LOG_DIR']} host-to-instance sym-ansible-test $HOST --json' ansible_aws_ssm_region='us-east-1' ansible_aws_ssm_profile='sym-ansible-test'",
+            f"--extra-vars=ansible_aws_ssm_bucket='sym-ansible-{TEST_ACCOUNT}' ansible_aws_ssm_host_cmd='sym --saml-client aws-profile --log-dir {os.environ['SYM_LOG_DIR']} host-to-instance sym-ansible-test $HOST --json' ansible_aws_ssm_region='us-east-1' ansible_aws_ssm_profile='sym-ansible-test' ansible_aws_ssm_timeout='120'",
         ]
         capture_command.assert_commands(
             [
