@@ -5,20 +5,24 @@ import tempfile
 
 import pytest
 from expects import *
-
-from sym.cli.helpers.contexts import push_env
-from sym.cli.helpers.os import cd
+from sym.shared.cli.helpers.contexts import push_env
+from sym.shared.cli.helpers.os import cd
 
 LD_DIR = "./test/integration/docker-ansible-ld/sym"
 
 pytestmark = pytest.mark.skipif(
-    not os.getenv("SYM_INTEGRATION"), reason="skipping integration tests",
+    not os.getenv("SYM_INTEGRATION"),
+    reason="skipping integration tests",
 )
 
 
 def run_login(config, run):
     run(
-        "login", "--email", config.getoption("email"), "--org", config.getoption("org"),
+        "login",
+        "--email",
+        config.getoption("email"),
+        "--org",
+        config.getoption("org"),
     )
 
 
@@ -26,6 +30,8 @@ def test_ssh_old_instance(pytestconfig, integration_runner):
     with integration_runner() as run:
         run_login(pytestconfig, run)
         result = run(
+            "--saml-client",
+            "aws-profile",
             "ssh",
             pytestconfig.getoption("resource"),
             pytestconfig.getoption("instance"),
@@ -43,6 +49,8 @@ def test_ansible_playbook_old_instance(pytestconfig, integration_runner):
             f.write(pytestconfig.getoption("instance") + "\n")
         with tempfile.TemporaryDirectory() as log_dir:
             result = run(
+                "--saml-client",
+                "aws-profile",
                 "--log-dir",
                 log_dir,
                 "ansible-playbook",
@@ -50,8 +58,9 @@ def test_ansible_playbook_old_instance(pytestconfig, integration_runner):
                 "-i",
                 "inventory.txt",
                 "docker_test.yml",
+                "-vvv",
             )
-        expect(result.output).to(contain("ok=3"))
+        expect(result.output).to(contain("ok=5"))
 
 
 @pytest.mark.skip(reason="Need to automate spinning up more instances")
@@ -70,11 +79,18 @@ def test_ansible_playbook_new_instance(pytestconfig, integration_runner):
                 "ec2.py",
                 "docker_test.yml",
             )
-        expect(result.output).to(contain("ok=3"))
+        expect(result.output).to(contain("ok=5"))
 
 
 def test_exec(pytestconfig, integration_runner):
     with cd(LD_DIR), integration_runner() as run:
         run_login(pytestconfig, run)
-        result = run("exec", pytestconfig.getoption("resource"), "--", "./ec2.py",)
+        result = run(
+            "--saml-client",
+            "aws-profile",
+            "exec",
+            pytestconfig.getoption("resource"),
+            "--",
+            "./ec2.py",
+        )
         expect(json.loads(result.output)).to(have_keys("_meta", "ec2"))
